Flask-OAuthlib-Invenio
======================

WARNING: This is a private fork of Flask-OAuthlib used for Invenio. Please follow the notes of `Flask-OAuthlib <https://github.com/lepture/flask-oauthlib>`_ instead.

this fork is not endorsed by the original author.
